var port = chrome.runtime.connect({
    name: "hello",
});

import {
    contentTwitterPinLogin,
    renderDom,
    showGiveDialogHandler,
    showIframeHandler,
    hideIframeHandler,
    showTwitterPublishDialogHandler,
    setIframeRedPacket,
    showPinTips,
    addPinedPop
} from "../logic/twitter.js";

import { getChromeStorage } from "@/uilts/chromeExtension";

port.onMessage.addListener(function (res) {
    switch (res.state) {
        case "BACK_TWITTER_LOGIN_SUCCESS":
            showGiveDialogHandler();
            break;
    }
});

chrome.storage.onChanged.addListener(changes => {
    if (changes.executeScript) {
        let item = JSON.parse(changes.executeScript.newValue)
        if (item.executeScript) {
            init()
        }
    }
})

window.onload = () => {
    init()
};

function init() {
    if (window.location.href.indexOf('twitter.com') < 0) {
        return
    }
    contentTwitterPinLogin(port);
    renderDom(port);
    setIframeRedPacket();

    getChromeStorage("popupShowPublishDialog", (res) => {
        console.log("popupShowPublishDialog", res);
        if (res && res.show) {
            setTimeout(() => {
                showTwitterPublishDialogHandler({
                    srcContent: res.srcContent,
                    postId: res.postId
                });
            }, 1500);
            chrome.storage.local.remove("popupShowPublishDialog");
        }
    });
    getChromeStorage("userSettings", (res) => {
        addPinedPop();
        if (res && !res.isOnToolbar) {
            setTimeout(() => {
                showPinTips();
                chrome.storage.local.remove("userSettings");
            }, 800);
        }
    });
}

window.onmessage = (res) => {
    if (res.data && res.data.actionType) {
        switch (res.data.actionType) {
            case "IFRAME_SHOW_IFREME":
                showIframeHandler();
                break;
            case "IFRAME_HIDE_IFREME":
                hideIframeHandler();
                break;
            case "IFRAME_SHOW_TWITTER_PUBLISH_DIALOG":
                showTwitterPublishDialogHandler(res.data.publishRes);
                break;
        }
    }
};

chrome.runtime.onMessage.addListener((req, sender, sendResponse) => {
    sendResponse('');
    switch(req.actionType) {
        case 'BG_SHOW_PIN_TIPS':
            showPinTips()
            break;
    }
})